# SPDX-FileCopyrightText: 2023 Civic Hacker, LLC
#
# SPDX-License-Identifier: GPL-3.0-or-later

import csv

PREFIX_TYPES = [
    "mathematical",
    "empty"
]

SUFFIX_TYPES = [
    'numerical',
    'mathematical',
    'empty'
]

NAME_SOURCES = [
    "male_klingon",
    "exoplanets",
    "female_klingon"
]

MATHEMATICAL = [
    'Alpha',
    'Prime',
    'Beta',
    'Rho',
    'Delta',
    'Omega',
    'Epsilon',
    'Theta'
]

EXOPLANETS = list()
STARNAMES = list()

with open('./data/NameExoWorlds.csv', 'r') as f:
    reader = csv.DictReader(f)
    for line in reader:
        EXOPLANETS.append(line.get("Name Exoplanet"))
        STARNAMES.append(line.get("Name Star"))



# SPDX-FileCopyrightText: 2023 Civic Hacker, LLC
#
# SPDX-License-Identifier: GPL-3.0-or-later

from typing import Generator
import random

from otherworlds.klingon import FEMALE_KLINGON, MALE_KLINGON
from otherworlds.exoplanets import EXOPLANETS, STARNAMES

DEFAULT_SEED = 270055

PREFIX_TYPES = [
    "mathematical",
    "empty"
]


SUFFIX_TYPES = [
    'numerical',
    'mathematical',
    'empty'
]

NAME_SOURCES = [
    "starnames",
    "exoplanets"
]

MATHEMATICAL = [
    'Alpha',
    'Prime',
    'Beta',
    'Rho',
    'Delta',
    'Omega',
    'Epsilon',
    'Theta'
]

KLINGON = [nom for slist in zip(FEMALE_KLINGON, MALE_KLINGON) for nom in slist]


def generate_name(
      generator: random.Random = random.Random(DEFAULT_SEED),
      include_klingon: bool = False) -> Generator[str, None, None]:

    name_list = EXOPLANETS + STARNAMES
    if include_klingon:
        name_list += KLINGON

    while True:
        name = generator.choice(name_list)
        nsuffix = f'{generator.randrange(999, 9999)}'
        msuffix = generator.choice(MATHEMATICAL)
        yield f'{" ".join([name, msuffix, nsuffix]).strip()}'  # type: ignore



# SPDX-FileCopyrightText: 2023 Civic Hacker, LLC
#
# SPDX-License-Identifier: GPL-3.0-or-later

def slugify(original_string: str) -> str:
    s_encode = original_string.encode('ascii', 'ignore')
    s_decode = s_encode.decode()
    return s_decode.replace("'", '').replace(' ', '-').lower()



# SPDX-FileCopyrightText: 2023 Civic Hacker, LLC
#
# SPDX-License-Identifier: GPL-3.0-or-later

FEMALE_KLINGON = [
    "Azetbur",
    "B'Etor",
    "Ba'el",
    "Ch'Rega",
    "Ezri",
    "Grilka",
    "Jadzia Dax",
    "K'Ehleyr",
    "Lursa",
    "Miral",
    "Valkris",
]

MALE_KLINGON = [
    "Antaak",
    "Atul",
    "Brota",
    "Klaang",
    "Kol",
    "Kol-Sha",
    "Magh",
    "Maltz",
    "Orak",
    "Rodek",
    "Sisko",
    "Toral",
    "Voq",
]
